package net.wanji.opt.controllerv2.judgeanalysis;

import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.greenproblem.GreenProblemTimeDirReasonResult;
import net.wanji.opt.entity.judgeanalysis.AiOptimizeStatistic;
import net.wanji.opt.servicev2.judgeanalysis.AiOptimizeStatisticService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import net.wanji.opt.api.ResultGenerator;



import javax.validation.Valid;
import javax.ws.rs.core.MediaType;
import java.util.List;
import java.util.Map;

/**
* <p>
* AI优化时长 前端控制器
* </p>
*
* @author fengyi
* @since 2025-03-24
*/
@Api(tags = "AI优化时长")
@RestController
@RequestMapping("/ai-optimize-statistic")
@Slf4j
public class AiOptimizeStatisticController {


    @Autowired
    private AiOptimizeStatisticService aiOptimizeStatisticService;



    @ApiOperation(value = "AI优化时长详情", response = AiOptimizeStatistic.class)
    @GetMapping(value = "/info/{id}")
    public  Object info(@PathVariable Long id) {

        Object data = aiOptimizeStatisticService.info(id);
         return ResultGenerator.genSuccessResult(data);
    }

    @ApiOperation(value = "AI优化时长新增")
    @PostMapping(value = "/add")
    public  Object add(@Valid @RequestBody AiOptimizeStatistic param) {

        aiOptimizeStatisticService.add(param);
        return ResultGenerator.genSuccessResult();
    }

    @ApiOperation(value = "AI优化时长修改")
    @PostMapping(value = "/modify")
    public  Object modify(@Valid @RequestBody AiOptimizeStatistic param) {

        aiOptimizeStatisticService.modify(param);
        return ResultGenerator.genSuccessResult();
    }

    @ApiOperation(value = "AI优化时长删除(单个条目)")
    @GetMapping(value = "/remove/{id}")
    public  Object remove(@PathVariable Long id) {

        aiOptimizeStatisticService.remove(id);
        return ResultGenerator.genSuccessResult();
    }

    @ApiOperation(value = "AI优化时长删除(多个条目)")
    @PostMapping(value = "/removes")
    public  Object removes(@Valid @RequestBody List<Long> ids) {

        aiOptimizeStatisticService.removes(ids);
        return ResultGenerator.genSuccessResult();
    }

    @ApiOperation(value = "绿波干线-绿波优化次数",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "greenId", value = "绿波干线", required = true, dataType = "string", defaultValue = "1"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @GetMapping(value = "/optimize")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenProblemTimeDirReasonResult.class),
    })
    public JsonViewObject detail(String greenId,Integer startTime, Integer endTime) {

        JsonViewObject jsonView =JsonViewObject.newInstance();

        try {
            Map<String,Object> resDate = aiOptimizeStatisticService.greenOptimizeByTimeTrend(greenId,startTime,endTime);
            jsonView.success(resDate);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }

        return jsonView;
    }


}