package net.wanji.opt.controllerv2.judgeanalysis;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaCrossProblemAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaGreenProblemAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaProblemOverview;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaProblemTrendAnalysisResult;
import net.wanji.opt.entity.judgeanalysis.AnalysisProblemCrossDay;
import net.wanji.opt.servicev2.judgeanalysis.AnalysisProblemAreaDayService;
import net.wanji.opt.servicev2.judgeanalysis.AnalysisProblemCrossDayService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 绿波问题分析 前端控制器
 * </p>
 *
 * @author fengyi
 * @since 2025-03-13
 */
@Api(tags = "研判分析-区域问题分析")
@Slf4j
@RestController
@RequestMapping("/analysis-area-problem")
public class AnalysisProblemAreaDayController {

    @Autowired
    private AnalysisProblemAreaDayService analysisProblemAreaDayService;

    @ApiOperation(value = "区域-问题数量总览", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/overview")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "areaId", value = "区域ID", required = true, dataType = "String", defaultValue = "12"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemOverview.class),
    })
    public JsonViewObject areaProblemOverview(Integer areaId, Integer startTime, Integer endTime) {
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {

            List<AnalysisProblemCrossDay> list = analysisProblemAreaDayService.selectCountByType(areaId,startTime,endTime);
            jsonView.success(list);
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }


    @ApiOperation(value = "区域-问题数量趋势分析", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/trend")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "areaId", value = "区域ID", required = true, dataType = "Integer", defaultValue = "12"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemTrendAnalysisResult.class),
    })
    public JsonViewObject trend(Integer areaId,  Integer startTime, Integer endTime) {
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            Map<String,Object> retData = analysisProblemAreaDayService.selectAreaProblemTrend(areaId,startTime,endTime);
            jsonView.success(retData);
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }


    @ApiOperation(value = "区域-路口问题数量分析", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "eventType", value = "事件代码 701：路口空放 702：路口失衡，703：路口溢出 707：路口拥堵", required = true, dataType = "String", defaultValue = ""),
            @ApiImplicitParam(name = "areaId", value = "区域ID", required = true, dataType = "String", defaultValue = "12"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),

    })
    @GetMapping(value = "/cross-problem-number")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaCrossProblemAnalysisResult.class),
    })
    public JsonViewObject crossProblemNumber(String eventType, Integer areaId,  Integer startTime, Integer endTime) {
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<Map<String,Object>> retData = analysisProblemAreaDayService.selectCrossAllProblemNums(eventType,areaId,startTime,endTime);
            jsonView.success(retData);
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }


    @ApiOperation(value = "区域-干线问题数量分析", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "eventType", value = "事件代码  705:干线缓行 706：干线拥堵  ", required = true, dataType = "String", defaultValue = ""),
            @ApiImplicitParam(name = "areaId", value = "区域ID", required = true, dataType = "String", defaultValue = "12"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @GetMapping(value = "/green-problem-number")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaGreenProblemAnalysisResult.class),
    })
    public JsonViewObject greenProblemNumber(String eventType, Integer areaId,  Integer startTime, Integer endTime) {
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<Map<String,Object>> retData = analysisProblemAreaDayService.selectGreenAllProblemNums(eventType,areaId,startTime,endTime);
            jsonView.success(retData);
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }

}
