package net.wanji.opt.controllerv2.judgeanalysis;

import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaProblemOverview;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaProblemTrendAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.crossproblem.CrossDirProblemTrendAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.crossproblem.CrossProblemDirTrendAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.crossproblem.CrossProblemDistributeAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.crossproblem.CrossProblemTimeDirReasonResult;
import net.wanji.opt.entity.judgeanalysis.AnalysisProblemCrossDay;
import net.wanji.opt.servicev2.judgeanalysis.AnalysisProblemCrossDayService;
import net.wanji.opt.vo2.CrossOptAnalysisVO;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.ws.rs.core.MediaType;
import java.util.List;
import java.util.Map;

/**
* <p>
* 路口问题分析 前端控制器
* </p>
*
* @author fengyi
* @since 2025-03-13
*/
@Api(tags = "研判分析-路口问题分析")
@RestController
@RequestMapping("/analysis-problem-cross-day")
@Slf4j
public class AnalysisProblemCrossDayController {
    @Resource
    private AnalysisProblemCrossDayService analysisProblemCrossDayService;

    @ApiOperation(value = "单路口-问题数量总览",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String"),
//            @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = true, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "startTime", value = "开始时间", required = false, dataType = "String"),
            @ApiImplicitParam(name = "endTime", value = "结束时间", required = false, dataType = "String"),
    })
    @GetMapping(value = "/overview")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemOverview.class),
    })

    public JsonViewObject problemOverview(String crossId,Integer startTime, Integer endTime) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
           try{
               List<AnalysisProblemCrossDay> list=analysisProblemCrossDayService.getListSingleByStartAndEnd(crossId,startTime,endTime);
               jsonViewObject.success(list);
           }catch (Exception e){
               jsonViewObject.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
               log.error("{} getAll error", this.getClass().getSimpleName(), e);
           }
        return jsonViewObject;
    }


    @ApiOperation(value = "单路口-路口报警走势",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String", defaultValue = "13MNM0B5OR0"),
//            @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = true, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @GetMapping(value = "/trend")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemTrendAnalysisResult.class),
    })
    public JsonViewObject trend(String crossId,Integer startTime, Integer endTime) {

        JsonViewObject jsonView=JsonViewObject.newInstance();
        try{
            Map<String,Object> resDate=analysisProblemCrossDayService.selectSingerByProblemTrend(crossId,startTime,endTime);
             jsonView.success(resDate);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }

        return jsonView;
    }



    @ApiOperation(value = "单路口-问题发生时段、方向、原因分析",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String"),
            @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = true, dataType = "Integer", defaultValue = "1"),
    })
    @GetMapping(value = "/detail")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossProblemTimeDirReasonResult.class),
    })
    public JsonViewObject detail(String crossId,String timeType) {
        return JsonViewObject.newInstance().success(null);
    }


    @ApiOperation(value = "单路口-各方向问题情况分布",   response = CrossProblemDirTrendAnalysisResult.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String"),
//            @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = true, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "eventType", value = "事件代码 701：空放 702：路口失衡，703：路口溢出 707：路口拥堵", required = true, dataType = "String"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @GetMapping(value = "/dir-trend")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossDirProblemTrendAnalysisResult.class),
    })
    public JsonViewObject dirTrend(String crossId,String eventType,Integer startTime, Integer endTime) {
        return JsonViewObject.newInstance().success(null);
    }

    @ApiOperation(value = "路口报警优化分析", notes = "路口报警优化分析", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossID", value = "路口ID", required = true, dataType = "String"),
            @ApiImplicitParam(name = "startTime", value = "日期,格式：yyyy-MM-dd HH:mm:ss", required = true, dataType = "String"),
            @ApiImplicitParam(name = "endTime", value = "日期,格式：yyyy-MM-dd HH:mm:ss", required = true, dataType = "String"),
    })
    @GetMapping(value = "/getCrossOptAnalysis")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossOptAnalysisVO.class),
    })
    public JsonViewObject getCrossOptAnalysis(String crossID, String startTime,String endTime) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try {
            CrossOptAnalysisVO info = analysisProblemCrossDayService.getCrossOptAnalysis(crossID, startTime,endTime);
            return jsonViewObject.success(info);
        } catch (Exception e) {
            log.error("获取路口优化分析失败", e);
            return jsonViewObject.fail("获取路口优化分析失败");
        }
    }


    @ApiOperation(value = "路口事件数按事件数/持续时间分布情况", notes = "路口事件数按事件数/持续时间分布情况", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String"),
            @ApiImplicitParam(name = "startTime", value = "查询截止时间，格式yyyy-MM-dd HH:mm:ss", required = true, dataType = "String"),
            @ApiImplicitParam(name = "endTime", value = "查询截止时间，格式yyyy-MM-dd HH:mm:ss", required = true, dataType = "String"),
            @ApiImplicitParam(name = "groupType", value = "时间粒度类型 0：5分钟粒度 1：15分钟粒度 2：30分钟粒度 3：小时粒度 4：天粒度", required = true, dataType = "Integer",defaultValue = "1"),
    })
    @GetMapping(value = "/getCrossOptimizeDistribute")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossProblemDistributeAnalysisResult.class),
    })
    public JsonViewObject getCrossOptimizeDistribute(String crossId, String startTime, String endTime, String groupType) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try {
            return jsonViewObject.success();
        } catch (Exception e) {
            log.error("路口事件数按事件数/持续时间分布情况", e);
            return jsonViewObject.fail("路口事件数按事件数/持续时间分布情况失败");
        }
    }



}