package net.wanji.opt.controllerv2.judgeanalysis;


import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaProblemOverview;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaProblemTrendAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.crossproblem.CrossProblemDirTrendAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.greenproblem.GreenCrossProblemTrendAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.greenproblem.GreenProblemTimeDirReasonResult;
import net.wanji.opt.entity.judgeanalysis.AnalysisProblemGreenDay;
import net.wanji.opt.servicev2.judgeanalysis.AnalysisProblemCrossDayService;
import net.wanji.opt.servicev2.judgeanalysis.AnalysisProblemGreenDayService;
import net.wanji.opt.vo2.CrossOptAnalysisVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.ws.rs.core.MediaType;
import java.util.List;
import java.util.Map;

/**
* <p>
* 绿波问题分析 前端控制器
* </p>
*
* @author fengyi
* @since 2025-03-13
*/
@Api(tags = "研判分析-绿波问题分析")
@RestController
@RequestMapping("/analysis-problem-green-day")
@Slf4j
public class AnalysisProblemGreenDayController {


    @Autowired
    private AnalysisProblemGreenDayService analysisProblemGreenDayService;
    @Resource
    private AnalysisProblemCrossDayService analysisProblemCrossDayService;



    @ApiOperation(value = "绿波干线-问题数量总览",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "greenId", value = "绿波干线", required = true, dataType = "Integer"),
           // @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = false, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @GetMapping(value = "/overview")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemOverview.class),
    })
    public JsonViewObject problemOverview(Integer greenId,Integer startTime,Integer endTime) {

            JsonViewObject jsonView= JsonViewObject.newInstance();
        try {
            List<AnalysisProblemGreenDay> list= analysisProblemGreenDayService.getListGreenByProblemSum(greenId,startTime,endTime);
            jsonView.success(list);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
            return jsonView;
    }


    @ApiOperation(value = "绿波干线-报警走势",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "greenId", value = "绿波干线", required = true, dataType = "Integer"),
           // @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = false, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @GetMapping(value = "/trend")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemTrendAnalysisResult.class),
    })
    public JsonViewObject trend(Integer greenId,Integer startTime, Integer endTime) {
        JsonViewObject jsonView=JsonViewObject.newInstance();
        try{
            Map<String,Object> resDate=analysisProblemGreenDayService.getListGreenByProblemTrend(greenId,startTime,endTime);
            jsonView.success(resDate);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }

        return jsonView;
    }



    @ApiOperation(value = "绿波干线-问题发生时段、方向、原因分析",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "greenId", value = "绿波干线", required = true, dataType = "Integer", defaultValue = "1"), 
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @GetMapping(value = "/detail")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenProblemTimeDirReasonResult.class),
    })
    public JsonViewObject detail(Integer greenId,String timeType) {
        return JsonViewObject.newInstance().success(null);
    }


    @ApiOperation(value = "绿波干线-干线路口问题情况分布",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "greenId", value = "绿波干线", required = true, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = false, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "eventType", value = "事件代码 701：空放 702：路口失衡，703：路口溢出 707：路口拥堵", required = true, dataType = "String", defaultValue = "705"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @GetMapping(value = "/cross-trend")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenCrossProblemTrendAnalysisResult.class),
    })
    public JsonViewObject dirTrend(Integer greenId,String timeType,String eventType) {
        return JsonViewObject.newInstance().success(null);
    }


    @ApiOperation(value = "干线报警优化分析概览【左侧】", notes = "干线报警优化分析", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "greenId", value = "greenId", required = true, dataType = "String"),
            @ApiImplicitParam(name = "startTime", value = "日期,格式：yyyy-MM-dd HH:mm:ss", required = true, dataType = "String"),
            @ApiImplicitParam(name = "endTime", value = "日期,格式：yyyy-MM-dd HH:mm:ss", required = true, dataType = "String"),
    })
    @GetMapping(value = "/getGreenOptAnalysis")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossOptAnalysisVO.class),
    })
    public JsonViewObject getGreenOptAnalysis(String greenId, String startTime,String endTime) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try {
            CrossOptAnalysisVO info = analysisProblemGreenDayService.getGreenOptAnalysis(greenId, startTime,endTime);
            return jsonViewObject.success(info);
        } catch (Exception e) {
            log.error("获取路口优化分析失败", e);
            return jsonViewObject.fail("获取路口优化分析失败");
        }
    }

}