package net.wanji.opt.controllerv2.judgeanalysis;

import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.greenproblem.GreenCrossProblemTrendAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.greenproblem.GreenProblemTimeDirReasonResult;
import net.wanji.opt.entity.judgeanalysis.AnalysisProblemGreenHour;
import net.wanji.opt.servicev2.judgeanalysis.AnalysisProblemGreenHourService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import net.wanji.opt.api.ResultGenerator;



import javax.validation.Valid;
import javax.ws.rs.core.MediaType;
import java.util.List;
import java.util.Map;

/**
* <p>
* 干线按小时粒度问题分析 前端控制器
* </p>
*
* @author fengyi
* @since 2025-03-21
*/
@Api(tags = "干线按小时粒度问题分析")
@RestController
@RequestMapping("/analysis-problem-green-hour")
@Slf4j
public class AnalysisProblemGreenHourController {


    @Autowired
    private AnalysisProblemGreenHourService analysisProblemGreenHourService;



    @ApiOperation(value = "干线按小时粒度问题分析详情", response = AnalysisProblemGreenHour.class)
    @GetMapping(value = "/info/{id}")
    public  Object info(@PathVariable Long id) {

        Object data = analysisProblemGreenHourService.info(id);
         return ResultGenerator.genSuccessResult(data);
    }

    @ApiOperation(value = "干线按小时粒度问题分析新增")
    @PostMapping(value = "/add")
    public  Object add(@Valid @RequestBody AnalysisProblemGreenHour param) {

        analysisProblemGreenHourService.add(param);
        return ResultGenerator.genSuccessResult();
    }

    @ApiOperation(value = "干线按小时粒度问题分析修改")
    @PostMapping(value = "/modify")
    public  Object modify(@Valid @RequestBody AnalysisProblemGreenHour param) {

        analysisProblemGreenHourService.modify(param);
        return ResultGenerator.genSuccessResult();
    }

    @ApiOperation(value = "干线按小时粒度问题分析删除(单个条目)")
    @GetMapping(value = "/remove/{id}")
    public  Object remove(@PathVariable Long id) {

        analysisProblemGreenHourService.remove(id);
        return ResultGenerator.genSuccessResult();
    }

    @ApiOperation(value = "干线按小时粒度问题分析删除(多个条目)")
    @PostMapping(value = "/removes")
    public  Object removes(@Valid @RequestBody List<Long> ids) {

        analysisProblemGreenHourService.removes(ids);
        return ResultGenerator.genSuccessResult();
    }

    @ApiOperation(value = "绿波干线-干线路口问题情况分布",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "greenId", value = "绿波干线", required = true, dataType = "Integer", defaultValue = "1"),
           // @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = false, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "eventType", value = "事件代码 701：空放 702：路口失衡，703：路口溢出 707：路口拥堵", required = true, dataType = "String", defaultValue = "705"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
    })
    @GetMapping(value = "/cross-trend")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenCrossProblemTrendAnalysisResult.class),
    })
    public JsonViewObject dirTrend(Integer greenId, String eventType,Integer startTime, Integer endTime) {
        JsonViewObject jsonView = JsonViewObject.newInstance();

        try{
            Map<String,Object> resDate= analysisProblemGreenHourService.directionGreenByProblemTrend(greenId,eventType,startTime,endTime);
            jsonView.success(resDate);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }
    @ApiOperation(value = "绿波干线-问题发生时段、方向、原因分析",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "greenId", value = "绿波干线", required = true, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250317"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyyMMdd", required = false, dataType = "Integer", defaultValue = "20250318"),
            @ApiImplicitParam(name = "eventType", value = "事件代码 701：空放 702：路口失衡，703：路口溢出 707：路口拥堵", required = true, dataType = "String", defaultValue = "705"),
    })
    @GetMapping(value = "/detail")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenProblemTimeDirReasonResult.class),
    })
    public JsonViewObject detail(Integer greenId,String eventType,Integer startTime, Integer endTime) {

        JsonViewObject jsonView =JsonViewObject.newInstance();

         try {
             Map<String,Object>resDate = analysisProblemGreenHourService.detailGreenByProblemTrend(greenId,eventType,startTime,endTime);
             jsonView.success(resDate);
         }catch (Exception e){
             jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
             log.error("{} getAll error", this.getClass().getSimpleName(), e);
         }

         return jsonView;
    }

}