package net.wanji.opt.controllerv2.judgeanalysis;

import com.alibaba.fastjson.JSONObject;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.crosssignal.CrossSignalPlanReasonResult;
import net.wanji.opt.servicev2.judgeanalysis.CrossSignalPlanService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;

/**
 * <p>
 * 路口信号方案
 * </p>
 */
@RestController
@Slf4j
@RequestMapping("/cross-signal-plan")
@Api(value="CrossSignalPlanController", description="路口信号方案查询", tags = "路口信号方案查询")
public class CrossSignalPlanController {

    @Autowired
    private CrossSignalPlanService crossSignalPlanService;

    @ApiOperation(value = "路口信号方案查询",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "startTime", value = "开始时间,格式：yyyy-MM-dd HH:mm:ss", required = false, dataType = "Integer", defaultValue = "2025-03-17 00:00:00"),
            @ApiImplicitParam(name = "endTime", value = "结束时间,格式：yyyy-MM-dd HH:mm:ss", required = false, dataType = "Integer", defaultValue = "2025-03-19 00:00:00"),
    })
    @GetMapping(value = "/getByDateScope")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossSignalPlanReasonResult.class),
    })
    public JsonViewObject getByDateScope(String crossId,String startTime,String endTime) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try {
            JSONObject jsonObject = crossSignalPlanService.getByDateScope(crossId,startTime,endTime);
           return jsonViewObject.success(jsonObject);
        } catch (Exception e) {
            jsonViewObject.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonViewObject;
    }

}
